
/******* Table 1 - Descriptives ******** 

This .do file generates the descriptive table for the paper Sending the Pork Home. 

Note: requires esttab

****************************************/


* Panel A - Descriptive statistics for MUNICIPALITIES *

clear
use ../../Data/Data_final.dta, replace

gen dum_w = (dum_w_int == 1 | dum_w_ext == 1 | dum_w_prop == 1) if dum_w_int != .
gen municip_with_repres =  dum_w*100 	// % of municipalities with at least one MP


* Labeling *
label var  municip_with_repres "Municipalities with at least 1 repr (\%)"

* Order variables *
order population transfers_pc surface density municip_with_repres


* Insert a blank space (aestetics) *
foreach v of varlist population - municip_with_repres{
	label variable `v' `"\hspace{0.1cm} `: variable label `v''"'
}
*

eststo clear

estpost tabstat population - municip_with_repres if election == 1,  stat(mean sd) columns(statistics)
eststo A

estpost tabstat population - municip_with_repres if election == 2,  stat(mean sd) columns(statistics)
eststo B

estpost tabstat population - municip_with_repres if election == 3,  stat(mean sd) columns(statistics)
eststo C


esttab A B C using ../../Tables/Dtable1.tex, replace label /*
*/ mtitle("\textbf{1994-1995}" "\textbf{1996-2000}" "\textbf{2001-2005}") refcat(population "\textbf{Panel A: Municipalities}",nolabel) /*
*/ f nogaps noobs nonum booktabs collabels(none) plain /*
*/ cells(mean(fmt(1)) sd(fmt(1) par )) width(\hsize)   // Standard error in this table, not SD!


* N. of observations *
eststo clear

estpost tabstat transfers_pc  if year == 1994,  stat(count) 
eststo A1

estpost tabstat transfers_pc  if year == 1996 ,  stat(count) 
eststo A2

estpost tabstat transfers_pc  if year == 2001 ,  stat(count) 
eststo A3

esttab A1 A2 A3  using ../../Tables/Dtable1.tex, append label /*
*/ f nogaps noobs nonum nomtitles booktabs collabels(none) plain rename(transfers_pc Observations) /*
*/ cells(count mean) width(\hsize) 


* Panel B - Descriptive statistics for POLITICIANS *

use ../../Data/Data_Parliament.dta, replace
set more off

* Labeling *
label var  age "Age"

gen male_100 = 100*male
label var  male_100 "Male (\%)"

gen high_education = 100*(education_level >=4)
label var  high_education "College or higher (\%)"

label var avg_income "Income (thousand Euros)"
 
label var parl_exp_length "Previous exp. in the Parliament (years)"

gen past_appointment_gov100 = 100*past_appointment_gov
label var past_appointment_gov100 "Previous exp. in the Government"

gen past_counc_prov100 = 100*past_counc_prov
label var past_counc_prov100 "Previous exp. at the province level"

gen past_mayor100 = 100*past_mayor
label var past_mayor100 "Previous exp. as mayor"

gen past_pol_national100 = 100*past_pol_national
label var past_pol_national100 "Previous exp. as national party member"

gen past_pol_local100 = 100*past_pol_local
label var past_pol_local100 "Previous exp. as local party member"

order age male_100 high_education avg_income parl_exp_length past_appointment_gov100 past_counc_prov100 past_mayor100 past_pol_national100 past_pol_local100


* 1) Initialize table with Age *

* Internal = 1 - mean *
capture drop x
generate x = 1  if interior == 1   

quietly regress  age x if interior == 1, noconst
eststo A1

* External  = 1 - mean *
capture drop x
quietly generate x = 1  if exterior == 1

quietly regress  age x if exterior == 1, noconst
eststo A2

* Proportional  = 1 - mean *
capture drop x
gen proportional = (exterior == 0 & interior == 0)
quietly generate x = 1  if proportional == 1

quietly regress  age x if proportional == 1, noconst
eststo A3

* Difference column * 
preserve
drop if prop == 1

regress age interior
eststo B 
restore

esttab A1 A2 A3 B using ../../Tables/Dtable1.tex, append drop(_cons) label  rename(x age interior age exterior age proportional age)  /*
*/ mtitle("\textbf{Internals}" "\textbf{Externals}" "\textbf{Prop.}"  "\textbf{Int-ext}") refcat(age "\textbf{Panel B: Parliamentarians}", nolabel) /*
*/ f nogaps  noobs nonum  booktabs collabels(none) plain  /*
*/  cells(b(fmt(1 4 2))) width(\hsize)   // Standard error in this table, not SD!


* Standard deviations / standard errors * 
estpost su age if interior==1
mat deviaz = e(sd)
estadd scalar sca1 = deviaz[1,1]
est store A1

estpost su age if exterior == 1
mat deviaz = e(sd)
estadd scalar sca1 = deviaz[1,1]
est store A2

estpost su age if proportional == 1
mat deviaz = e(sd)
estadd scalar sca1 = deviaz[1,1]
est store A3

preserve
drop if prop
quietly regress age interior
mat var = e(V)
estadd scalar sca1 = sqrt(var[1,1])
eststo B 
restore 

label var age " "
esttab A1 A2 A3 B using ../../Tables/Dtable1.tex,  append nomtitles nonum cells(fff(fmt(1 4 2)))  s(sca1, label(" ")) /*
*/ collabels(none) nogaps plain noobs f label 

* Note: there is a trick used here. cells specifies a variable, fff, that does not exist. This is used to get the correct layout 
* and to specify the format of the numbers in sca1 (a vector where the numbers are)


* 2) Panel B continues: rest of the variables *

foreach i of varlist  male_100 - past_pol_local100{

* Internal = 1 - mean *
capture drop x
generate x = 1  if interior == 1   

quietly regress  `i' x if interior == 1, noconst
eststo A1

* External  = 1 - mean *
capture drop x
quietly generate x = 1  if exterior == 1

quietly regress  `i' x if exterior == 1, noconst
eststo A2

* Proportional  = 1 - mean *
capture drop x
quietly generate x = 1  if proportional == 1

quietly regress  `i' x if proportional == 1, noconst
eststo A3

* Difference column * 
preserve
drop if prop == 1

regress `i' interior
eststo B 
restore

esttab A1 A2 A3 B using ../../Tables/Dtable1.tex, append drop(_cons) label  rename(x `i' interior `i' exterior `i' proportional `i')  /*
*/ f  booktabs nonum collabels(none)  nostar  nomtitles plain /*
*/ cells(b(fmt(1 4 2))) noobs nogaps  width(\hsize)

* Standard deviations / standard errors * 
estpost su `i' if interior==1
mat deviaz = e(sd)
estadd scalar sca1 = deviaz[1,1]
est store A1

estpost su `i' if exterior == 1
mat deviaz = e(sd)
estadd scalar sca1 = deviaz[1,1]
est store A2

estpost su `i' if proportional == 1
mat deviaz = e(sd)
estadd scalar sca1 = deviaz[1,1]
est store A3

preserve
drop if prop
quietly regress `i' interior
mat var = e(V)
estadd scalar sca1 = sqrt(var[1,1])
eststo B 
restore 

label var `i' " "
esttab A1 A2 A3 B using ../../Tables/Dtable1.tex,  append nomtitles nonum cells(fff(fmt(1 4 2)))  s(sca1, label(" ")) /*
*/ collabels(none) nogaps plain noobs f label 

}
*

* 3) Finally:  N. of observations (use enter as it is always nonmissing) *

estpost tabstat enter  if interior == 1 ,  stat(count) 
eststo A1

estpost tabstat enter  if exterior == 1,  stat(count) 
eststo A2

estpost tabstat enter  if proportional == 1 ,  stat(count) 
eststo A3

estpost tabstat enter  if  (interior == 1 |  exterior == 1) ,  stat(count) 
eststo B

esttab A1 A2 A3 B  using ../../Tables/Dtable1.tex, append label /*
*/ f nogaps noobs nonum nomtitles booktabs collabels(none) plain rename(enter Observations) /*
*/ cells(count mean) width(\hsize) 


